==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/fr.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Chargement de la prévisualisation...",
    "Saved" : "Enregistré",
    "Admin" : "Administration",
    "a safe home for all your data" : "un endroit sûr pour toutes vos données",
    "Name cannot be empty" : "Le nom ne peut pas être vide",
    "The given name is too long" : "Le nom donné est trop long",
    "The given web address is too long" : "L'adresse web donnée est trop longue",
    "The given legal notice address is too long" : "L'adresse fournie pour la notice légale est trop longue",
    "The given privacy policy address is too long" : "L'adresse de la politique de confidentialité est trop longue",
    "The given slogan is too long" : "Le slogan donné est trop long",
    "The given color is invalid" : "La couleur donnée est invalide",
    "The file was uploaded" : "Le fichier a été téléversé",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Le fichier téléversé dépasse la valeur upload_max_filesize située dans le fichier php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le fichier téléversé dépasse la valeur MAX_FILE_SIZE spécifiée dans le formulaire HTML",
    "The file was only partially uploaded" : "Le fichier n'a été que partiellement envoyé",
    "No file was uploaded" : "Aucun fichier téléversé",
    "Missing a temporary folder" : "Absence de dossier temporaire",
    "Could not write file to disk" : "Impossible d'écrire le fichier sur le disque",
    "A PHP extension stopped the file upload" : "Une extension PHP a arrêté le téléversement du fichier",
    "No file uploaded" : "Aucun fichier téléversé",
    "Unsupported image type" : "Ce type d'image n'est pas pris en charge",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Vous utilisez déjà un thème personnalisé. Les paramètres de l'application Theming peuvent être remplacés par ceux-ci.",
    "Theming" : "Personnaliser l'apparence",
    "Legal notice" : "Notice légale",
    "Privacy policy" : "Politique de confidentialité",
    "Adjust the Nextcloud theme" : "Modifier le thème Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Cette extension permet de personnaliser facilement l'apparence de votre instance et des clients supportés. La personnalisation de l'apparence sera visible par tous les utilisateurs.",
    "Name" : "Nom",
    "Reset to default" : "Restaurer les valeurs par défaut",
    "Web link" : "Lien web",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Couleur",
    "Logo" : "Logo",
    "Upload new logo" : "Téléverser un nouveau logo",
    "Login image" : "Image de connexion",
    "Upload new login background" : "Téléverser un nouvel arrière-plan de connexion",
    "Remove background image" : "Supprimer l'image en arrière-plan",
    "Advanced options" : "Options avancées",
    "Legal notice link" : "Lien vers la notice légale",
    "Privacy policy link" : "Lien de la politique de confidentialité",
    "Header logo" : "Logo d'en-tête",
    "Upload new header logo" : "Téléverser un nouveau logo d'en-tête",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Téléverser un nouveau favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installez l'extension PHP Imagemagick avec le support pour les images SVG afin de générer automatiquement les favicons sur base du logo téléversé et de la couleur.",
    "You are already using a custom theme" : "Vous utilisez déjà un thème personnalisé",
    "reset to default" : "Restaurer les valeurs par défaut",
    "Web address" : "Adresse web",
    "Web address https://…" : "Adresse du serveur https://…",
    "There is no error, the file uploaded with success" : "Aucune erreur, le fichier a été téléversé avec succès",
    "The uploaded file was only partially uploaded" : "Le fichier n'a été que partiellement téléversé",
    "Failed to write file to disk." : "Erreur d'écriture du fichier sur le disque.",
    "A PHP extension stopped the file upload." : "Une extension PHP a arrêté le téléversement du fichier."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/fr.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Chargement de la prévisualisation...",
    "Saved" : "Enregistré",
    "Admin" : "Administration",
    "a safe home for all your data" : "un lieu sûr pour toutes vos données",
    "Name cannot be empty" : "Le nom ne peut pas être vide",
    "The given name is too long" : "Le nom donné est trop long",
    "The given web address is too long" : "L'adresse web donnée est trop longue",
    "The given legal notice address is too long" : "L'adresse fournie pour la notice légale est trop longue",
    "The given privacy policy address is too long" : "L'adresse de la politique de confidentialité est trop longue",
    "The given slogan is too long" : "Le slogan donné est trop long",
    "The given color is invalid" : "La couleur donnée est invalide",
    "The file was uploaded" : "Le fichier a été téléversé",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Le fichier téléversé dépasse la valeur upload_max_filesize située dans le fichier php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le fichier téléversé dépasse la valeur MAX_FILE_SIZE spécifiée dans le formulaire HTML",
    "The file was only partially uploaded" : "Le fichier n'a été que partiellement envoyé",
    "No file was uploaded" : "Aucun fichier téléversé",
    "Missing a temporary folder" : "Absence de dossier temporaire",
    "Could not write file to disk" : "Impossible d'écrire le fichier sur le disque",
    "A PHP extension stopped the file upload" : "Une extension PHP a arrêté le téléversement du fichier",
    "No file uploaded" : "Aucun fichier téléversé",
    "Unsupported image type" : "Ce type d'image n'est pas pris en charge",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Vous utilisez déjà un thème personnalisé. Les paramètres de l'application Theming peuvent être remplacés par ceux-ci.",
    "Theming" : "Personnaliser l'apparence",
    "Legal notice" : "Notice légale",
    "Privacy policy" : "Politique de confidentialité",
    "Adjust the Nextcloud theme" : "Modifier le thème Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Cette extension permet de personnaliser facilement l'apparence de votre instance et des clients supportés. La personnalisation de l'apparence sera visible par tous les utilisateurs.",
    "Name" : "Nom",
    "Reset to default" : "Restaurer les valeurs par défaut",
    "Web link" : "Lien web",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Couleur",
    "Logo" : "Logo",
    "Upload new logo" : "Téléverser un nouveau logo",
    "Login image" : "Image de connexion",
    "Upload new login background" : "Téléverser un nouvel arrière-plan de connexion",
    "Remove background image" : "Supprimer l'image en arrière-plan",
    "Advanced options" : "Options avancées",
    "Legal notice link" : "Lien vers la notice légale",
    "Privacy policy link" : "Lien de la politique de confidentialité",
    "Header logo" : "Logo d'en-tête",
    "Upload new header logo" : "Téléverser un nouveau logo d'en-tête",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Téléverser un nouveau favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installez l'extension PHP Imagemagick avec le support pour les images SVG afin de générer automatiquement les favicons sur base du logo téléversé et de la couleur.",
    "There is no error, the file uploaded with success" : "Aucune erreur, le fichier a été téléversé avec succès",
    "The uploaded file was only partially uploaded" : "Le fichier n'a été que partiellement téléversé",
    "Failed to write file to disk." : "Erreur d'écriture du fichier sur le disque.",
    "A PHP extension stopped the file upload." : "Une extension PHP a arrêté le téléversement du fichier.",
    "You are already using a custom theme" : "Vous utilisez déjà un thème personnalisé",
    "Web address https://…" : "Adresse du serveur https://…"
},
"nplurals=2; plural=(n > 1);");
